@@ -4,7 +4,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <aktest.h>
+#include "aktest.h"
 
 #include "aggregatedfetchscope.h"
 #include "entities.h"
@@ -142,8 +142,6 @@ private Q_SLOTS:
         QVERIFY(!manager.itemFetchScope()->fetchTags());
         QVERIFY(!manager.itemFetchScope()->fetchRelations());
         QVERIFY(!manager.itemFetchScope()->fetchVirtualReferences());
-
-        QMetaObject::invokeMethod(&manager, "quit", Qt::DirectConnection);
     }
 };
 
