@@ -8,7 +8,7 @@
 
 #include <QSet>
 
-#include <private/protocol_p.h>
+#include "private/protocol_p.h"
 
 #include <memory>
 
