@@ -16,7 +16,7 @@
 #include "querybuilder.h"
 #include "selectquerybuilder.h"
 
-#include <private/dbus_p.h>
+#include "private/dbus_p.h"
 
 #include <QCoreApplication>
 #include <QDBusConnection>
@@ -42,8 +42,6 @@ DbUpdater::DbUpdater(const QSqlDatabase &database, const QString &filename)
 
 bool DbUpdater::run()
 {
-    Q_ASSERT(QThread::currentThread() == QCoreApplication::instance()->thread());
-
     // TODO error handling
     auto store = DataStore::dataStoreForDatabase(m_database);
     auto currentVersion = SchemaVersion::retrieveAll(store).at(0);
@@ -140,7 +138,7 @@ bool DbUpdater::parseUpdateSets(int currentVersion, UpdateSet::Map &updates) con
     }
 
     const QDomElement documentElement = document.documentElement();
-    if (documentElement.tagName() != QLatin1String("updates")) {
+    if (documentElement.tagName() != QLatin1StringView("updates")) {
         qCCritical(AKONADISERVER_LOG) << "Invalid update description file format";
         return false;
     }
@@ -148,7 +146,7 @@ bool DbUpdater::parseUpdateSets(int currentVersion, UpdateSet::Map &updates) con
     // iterate over the xml document and extract update information into an UpdateSet
     QDomElement updateElement = documentElement.firstChildElement();
     while (!updateElement.isNull()) {
-        if (updateElement.tagName() == QLatin1String("update")) {
+        if (updateElement.tagName() == QLatin1StringView("update")) {
             const int version = updateElement.attribute(QStringLiteral("version"), QStringLiteral("-1")).toInt();
             if (version <= 0) {
                 qCCritical(AKONADISERVER_LOG) << "Invalid version attribute in database update description";
@@ -165,15 +163,15 @@ bool DbUpdater::parseUpdateSets(int currentVersion, UpdateSet::Map &updates) con
             } else {
                 UpdateSet updateSet;
                 updateSet.version = version;
-                updateSet.abortOnFailure = (updateElement.attribute(QStringLiteral("abortOnFailure")) == QLatin1String("true"));
+                updateSet.abortOnFailure = (updateElement.attribute(QStringLiteral("abortOnFailure")) == QLatin1StringView("true"));
 
                 QDomElement childElement = updateElement.firstChildElement();
                 while (!childElement.isNull()) {
-                    if (childElement.tagName() == QLatin1String("raw-sql")) {
+                    if (childElement.tagName() == QLatin1StringView("raw-sql")) {
                         if (updateApplicable(childElement.attribute(QStringLiteral("backends")))) {
                             updateSet.statements << buildRawSqlStatement(childElement);
                         }
-                    } else if (childElement.tagName() == QLatin1String("complex-update")) {
+                    } else if (childElement.tagName() == QLatin1StringView("complex-update")) {
                         if (updateApplicable(childElement.attribute(QStringLiteral("backends")))) {
                             updateSet.complex = true;
                         }
@@ -226,6 +224,7 @@ bool DbUpdater::complexUpdate_25()
     qCDebug(AKONADISERVER_LOG) << "Starting database update to version 25";
 
     DbType::Type dbType = DbType::type(m_database);
+    auto store = DataStore::dataStoreForDatabase(m_database);
 
     QElapsedTimer ttotal;
     ttotal.start();
@@ -256,8 +255,8 @@ bool DbUpdater::complexUpdate_25()
         // It appears that more users than expected have the invalid "GID" part in their
         // PartTable, which breaks the migration below (see BKO#331867), so we apply this
         // wanna-be fix to remove the invalid part before we start the actual migration.
-        QueryBuilder qb(QStringLiteral("PartTable"), QueryBuilder::Delete);
-        qb.addValueCondition(QStringLiteral("PartTable.name"), Query::Equals, QLatin1String("GID"));
+        QueryBuilder qb(store, QStringLiteral("PartTable"), QueryBuilder::Delete);
+        qb.addValueCondition(QStringLiteral("PartTable.name"), Query::Equals, QLatin1StringView("GID"));
         qb.exec();
     }
 
@@ -321,7 +320,6 @@ bool DbUpdater::complexUpdate_25()
     qCDebug(AKONADISERVER_LOG) << "Migrating part types";
     {
         // Get list of all part names
-        auto store = DataStore::dataStoreForDatabase(m_database);
         QueryBuilder qb(store, QStringLiteral("PartTable"), QueryBuilder::Select);
         qb.setDistinct(true);
         qb.addColumn(QStringLiteral("PartTable.name"));
